@@ -48,51 +48,51 @@ void cmdline_parser_print_help (void) {
 "Build generic tunnels through HTTPS proxies using HTTP authentication\n"
 "\n"
 "Standard options:\n"
-// FIXME: "   -c, --config=FILE       Read config options from file\n"
-" -i, --inetd               Run from inetd (default: off)\n"
-" -a, --standalone=INT      Run as standalone daemon on specified port\n"
-// FIXME: " -f, --nobackground        Don't for tok background in standalone mode\n"
-" -p, --proxy=STRING        Local proxy host:port combination\n"
-" -r, --remproxy=STRING     Remote proxy host:port combination (using 2 proxies)\n"
-" -d, --dest=STRING         Destination host:port combination\n"
+// FIXME: "   -c, --config=FILE        Read config options from file\n"
+" -i, --inetd                Run from inetd (default: off)\n"
+" -a, --standalone=INT       Run as standalone daemon on specified port\n"
+// FIXME: " -f, --nobackground         Don't for tok background in standalone mode\n"
+" -p, --proxy=STRING         Local proxy host:port combination\n"
+" -r, --remproxy=STRING      Remote proxy host:port combination (using 2 proxies)\n"
+" -d, --dest=STRING          Destination host:port combination\n"
 #ifdef USE_SSL
-" -e, --encrypt             SSL encrypt data between local proxy and destination\n"
-" -E, --encrypt-proxy       SSL encrypt data between client and local proxy\n"
-" -X, --encrypt-remproxy    SSL encrypt data between local and remote proxy\n"
-" -W, --wa-bug-29744        Workaround ASF Bugzilla 29744: if SSL is active stop\n"
-"                           using it after CONNECT (might not work on all setups; see\n"
-"                           /usr/share/doc/proxytunnel/README.Debian.gz)\n"
-" -B, --buggy-encrypt-proxy Equivalent to -E -W, provided for backwards\n"
-"                           compatibility\n"
-" -L                        (legacy) enforce TLSv1 connection\n"
-" -T, --no-ssl3             Do not connect using SSLv3\n"
+" -e, --encrypt              SSL encrypt data between local proxy and destination\n"
+" -E, --encrypt-proxy        SSL encrypt data between client and local proxy\n"
+" -X, --encrypt-remproxy     SSL encrypt data between local and remote proxy\n"
+" -W, --wa-bug-29744         Workaround ASF Bugzilla 29744: if SSL is active stop\n"
+"                            using it after CONNECT (might not work on all setups; see\n"
+"                            /usr/share/doc/proxytunnel/README.Debian.gz)\n"
+" -B, --buggy-encrypt-proxy  Equivalent to -E -W, provided for backwards\n"
+"                            compatibility\n"
+" -L                         (legacy) enforce TLSv1 connection\n"
+" -T, --no-ssl3              Do not connect using SSLv3\n"
 #endif
 "\n"
 "Additional options for specific features:\n"
 #ifdef USE_SSL
-" -z, --no-check-certficate Don't verify server SSL certificate\n"
-" -C, --cacert=STRING       Path to trusted CA certificate or directory\n"
+" -z, --no-check-certificate Don't verify server SSL certificate\n"
+" -C, --cacert=STRING        Path to trusted CA certificate or directory\n"
 #endif
-" -F, --passfile=STRING     File with credentials for proxy authentication\n"
-" -P, --proxyauth=STRING    Proxy auth credentials user:pass combination\n"
-" -R, --remproxyauth=STRING Remote proxy auth credentials user:pass combination\n"
-// " -u, --user=STRING      Username for proxy authentication\n"
-// " -s, --pass=STRING      Password for proxy authentication\n"
-// " -U, --uservar=STRING   Environment variable that holds username\n"
-// " -S, --passvar=STRING   Environment variable that holds password\n"
-" -N, --ntlm                Use NTLM based authentication\n"
-" -t, --domain=STRING       NTLM domain (default: autodetect)\n"
-" -H, --header=STRING       Add additional HTTP headers to send to proxy\n"
-" -o STRING                 send custom Host Header\n"
+" -F, --passfile=STRING      File with credentials for proxy authentication\n"
+" -P, --proxyauth=STRING     Proxy auth credentials user:pass combination\n"
+" -R, --remproxyauth=STRING  Remote proxy auth credentials user:pass combination\n"
+// " -u, --user=STRING       Username for proxy authentication\n"
+// " -s, --pass=STRING       Password for proxy authentication\n"
+// " -U, --uservar=STRING    Environment variable that holds username\n"
+// " -S, --passvar=STRING    Environment variable that holds password\n"
+" -N, --ntlm                 Use NTLM based authentication\n"
+" -t, --domain=STRING        NTLM domain (default: autodetect)\n"
+" -H, --header=STRING        Add additional HTTP headers to send to proxy\n"
+" -o STRING                  send custom Host Header\n"
 #ifdef SETPROCTITLE
-" -x, --proctitle=STRING    Use a different process title\n"
+" -x, --proctitle=STRING     Use a different process title\n"
 #endif
 "\n"
 "Miscellaneous options:\n"
-" -v, --verbose             Turn on verbosity\n"
-" -q, --quiet               Suppress messages\n"
-" -h, --help                Print help and exit\n"
-" -V, --version             Print version and exit\n", PACKAGE);
+" -v, --verbose              Turn on verbosity\n"
+" -q, --quiet                Suppress messages\n"
+" -h, --help                 Print help and exit\n"
+" -V, --version              Print version and exit\n", PACKAGE);
 
 #ifndef HAVE_GETOPT_LONG
 	printf( "\n"
